package com.cultural.heritage.model.dto.order;

import com.cultural.heritage.model.dto.snapshot.GoodSnapshot;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;

@Data
@Schema(description = "订单明细添加请求体", requiredProperties = {"orderId", "goodSnapshot", "priceSnapshot", "quantity", "itemTotalAmount"})
public class OrderItemAddRequest implements Serializable {


    /**
     * 关联的订单id
     */
    @Schema(description = "关联的订单id(id > 0)", example = "542")
    private Long orderId;


    /**
     * 商品信息快照
     */
    @Schema(description = "订单商品信息")
    private GoodSnapshot goodSnapshot;


    /**
     * 商品单价快照
     */
    @Schema(description = "商品单价", example = "30")
    private Double priceSnapshot;


    /**
     * 购买数量
     */
    @Schema(description = "购买数量", example = "10")
    private Integer quantity;


    /**
     * 订单项金额（单价 * 数量）
     */
    @Schema(description = "订单项金额(单价 * 数量)", example = "300")
    private Double itemTotalAmount;


    /**
     * 预约日期
     */
    @Schema(description = "预约日期", example = "2024-11-09")
    private String reservationDate;


    /**
     * 预约的具体时间段
     */
    @Schema(description = "预约的具体时间段", example = "8:00-12:00")
    private String timeSlot;


    @Serial
    private static final long serialVersionUID = 1L;
}
