package com.cultural.heritage.model.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.extension.handlers.JacksonTypeHandler;
import com.cultural.heritage.model.dto.snapshot.AddressSnapshot;
import com.cultural.heritage.model.dto.snapshot.ContactsSnapshot;
import com.cultural.heritage.model.dto.snapshot.CouponSnapshot;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;
import java.util.Date;


/**
 * 订单
 * @TableName  order_total
 */
@Data
@TableName(value = "order_total", autoResultMap = true)
public class Order implements Serializable {


    /**
     * 订单id
     */
    @TableId(type = IdType.AUTO)
    private Long id;

    /**
     * 订单类别
     */
    private String orderType;

    /**
     * 订单编号
     */
    private String OrderNumber;


    /**
     * 用户id
     */
    private Long userId;


    /**
     * 用户昵称
     */
    @Schema(description = "用户昵称", example = "张三")
    private String userName;


    /**
     * 地址信息快照
     */
    @TableField(typeHandler = JacksonTypeHandler.class)
    private AddressSnapshot addressSnapshot;


    /**
     * 联系人信息快照
     */
    @TableField(typeHandler = JacksonTypeHandler.class)
    private ContactsSnapshot contactsSnapshot;

    /**
     * 优惠券信息快照
     */
    @TableField(typeHandler = JacksonTypeHandler.class)
    private CouponSnapshot couponSnapshot;



    /**
     * 订单总金额
     */
    private Double totalAmount;


    /**
     * 订单状态
     */
    private String orderStatus;


    /**
     * 订单备注
     */
    private String note;


    /**
     * 创建时间
     */
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date createTime;


    /**
     * 更新时间
     */
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date updateTime;


    /**
     * 是否删除
     */
    private Integer isDelete;


    @Serial
    private static final long serialVersionUID = 1L;
}
